@@ -130,7 +130,7 @@ class AppInstallApp(SimpleGtkbuilderApp):
             pass
 
         SimpleGtkbuilderApp.__init__(
-            self, path=options.datadir+"/trisquel-app-install.ui")
+            self, path=options.datadir+"/trisquel-app-install.ui", connect=True)
 
         self.channelsdir = options.desktopdir+"/channels"
         self.datadir = options.datadir
@@ -778,6 +778,14 @@ class AppInstallApp(SimpleGtkbuilderApp):
                 if "<b>" not in str(menuitem):
                     menuitem.iconname = "applications-" + \
                         str(menuitem).lower()[10:]
+                    if menuitem.iconname == "applications-programming":
+                        menuitem.iconname = "applications-development"
+                    if menuitem.iconname == "applications-sound &amp; video":
+                        menuitem.iconname = "applications-multimedia"
+                    if menuitem.iconname == "applications-system tools":
+                        menuitem.iconname = "applications-system"
+                    if menuitem.iconname == "applications-universal access":
+                        menuitem.iconname = "preferences-desktop-accessibility"
                 icon = self.icons.load_icon(menuitem.iconname, 24, 0)
             except GObject.GError:
                 try:
