@@ -18,7 +18,9 @@ STEPS_UPDATE_CACHE = [12, 25, 37, 50, 100]
 class GtkMainIterationProgress(apt.progress.base.OpProgress):
     """Progress that just runs the main loop"""
 
-    def update(self, percent):
+    def update(self, percent=None):
+        if percent is None:
+            return
         while Gtk.events_pending():
             Gtk.main_iteration()
 
@@ -43,7 +45,9 @@ class GtkOpProgressWindow(apt.progress.base.OpProgress):
         if parent is not None:
             self.window_progress.set_transient_for(parent)
 
-    def update(self, percent):
+    def update(self, percent=None):
+        if percent is None:
+            return
         self.window_progress.show()
         # if the old percent was higher, a new progress was started
         if self.old > percent:
